@@ -1,6 +1,6 @@
 import os, time
 from os.path import *
-import gnomeapplet, gtk, gtk.gdk, gconf, gnomevfs, gobject, bonobo, ORBit
+import gnomeapplet, gtk, gtk.gdk, gconf, gobject, bonobo, ORBit
 from gettext import gettext as _
 
 import colorblind, colorblind.ui
