@@ -1,5 +1,5 @@
 DATA_DIR = "/usr/local/share"
 LIB_DIR = "/usr/local/lib"
-VERSION = "0.15.9"
+VERSION = "0.16.0"
 PACKAGE = "gnome-mag"
-PYTHONDIR = "/usr/local/lib/python2.6/site-packages"
+PYTHONDIR = "/usr/local/lib/python2.6/dist-packages"
